% Quokka3 example for setting up IBC geometry using the simplified 'IBC' syntax
% all properties are made-up, does not represent a specific real cell

% this example defines a 'busbar-enhanced' domain, i.e. considering finger resistance and busbar region-influence in addition to the 'standard' domain
% it considers a gap between the main N-type and P-type regions
% it considers a J02-like recombination shunt at the interface between N-type and P-type region (in this case between gap-skin and n-type skin)

% (c) 2025 Andreas Fell

Syntax = 'IBC';

DomainType = 'busbar-enhanced';

CellThickness = 120;

FingerPitch = 2 mm;
BusbarPitch = 43 mm;

NSkin.Width = 0.5mm;
NContact.Width = 80;
NContact.OhmicResistivity = 3e-4;
NFinger.Width = 80;
NFinger.Rsheet = 3e-3;
NFinger.Length = 21mm;

NBusbar.SkinWidth = 500;
NBusbar.Width = 250;
NBusbar.ContactEnable = 1;
NBusbar.Contact.OhmicResistivity = 3e-4;


PSkin.WidthFromPitch = 1; % means that the width of the P-region is calculated from finger pitch, gap width and N-region width
PContact.Width = 80;
PContact.OhmicResistivity = 3e-4;
PFinger.Width = 80;
PFinger.Rsheet = 3e-3;
PFinger.Length = 21mm;

PBusbar.SkinWidth = 500;
PBusbar.Width = 250;
PBusbar.ContactEnable = 1;
PBusbar.Contact.OhmicResistivity = 3e-4;

NPShunt.Enable = 1; % apply some J02-losses representing a recombination-shunt at the interface between N-type and P-type region
NPShunt.OhmicResistivity = 1e10; % very high value to effectively disable ohmic shunt
NPShunt.J02 = 1e-9; 


Solver.SolutionType = 'light JV-curve';
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;


Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.TextZ.FrontText.Type = 'from Rtot'; % Text of front side is determined from rear Rtot measurement, settingsgroup Optical.TextZ.FrontRtot
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local'; % light-trapping is set to be modelled from internal optical properties of the skins; enables to consider current changes when area-fraction of rear-side skin region changes (e.g. when changing N/P region ratio)
Optical.TextZ.FrontRtot.Type = 'file';
Optical.TextZ.FrontRtot.File = 'Rtot_front.txt';
Optical.TextZ.FrontRtot.Extrapolation = 'RT-TMM';
Optical.TextZ.FrontRtot.SurfaceMorphology = 'Rantex-default';
Optical.TextZ.FrontRtot.MetalCorrection = 1;
Optical.TextZ.FrontRtot.MetalReflectivity.Type = 'file';
Optical.TextZ.FrontRtot.MetalReflectivity.File = 'Wittek_metal_R.txt';
Optical.TextZ.FrontRtot.SampleThickness = 160 um;
Optical.TextZ.FrontRtot.SampleTemperature = 20 degC;
Optical.ScaleGeneration = 1;


Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 2;
Bulk.Electrical.Recombination.Type = 'intrinsic plus fixed-lifetime';
Bulk.Electrical.Recombination.FixedLifetime = 5ms;


FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 250;
FullFrontSkin.Lumped.Electrical.ConductionType = 'n-type';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 2e-15;
FullFrontSkin.Lumped.Optical.Internal.Rint = 0.92; % ideal Lambertian front side reflectivity
FullFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

NSkin.ElectricalModelType = 'lumped';
NSkin.Lumped.Electrical.RsheetEnable = 1;
NSkin.Lumped.Electrical.Rsheet = 100;
NSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
NSkin.Lumped.Electrical.NonContactedRecombination.J0 = 2e-15;
NSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
NSkin.Lumped.Electrical.ContactedRecombination.J0 = 20e-15;
NSkin.Lumped.Optical.Internal.Rint = 0.9;
NSkin.Lumped.Optical.Internal.Diffuse = 1;
NSkin.Lumped.Optical.Internal.ApppType = 'user';
NSkin.Lumped.Optical.Internal.Appp = 0.02; % some parasitic absorption in N-region material layers

PSkin.ElectricalModelType = 'lumped';
PSkin.Lumped.Electrical.RsheetEnable = 1;
PSkin.Lumped.Electrical.Rsheet = 100;
PSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
PSkin.Lumped.Electrical.NonContactedRecombination.J0 = 5e-15;
PSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
PSkin.Lumped.Electrical.ContactedRecombination.J0 = 50e-15;
PSkin.Lumped.Optical.Internal.Rint = 0.9;
PSkin.Lumped.Optical.Internal.Diffuse = 1;
PSkin.Lumped.Optical.Internal.ApppType = 'user';
PSkin.Lumped.Optical.Internal.Appp = 0.05; % high parasitic absorption in P-region material layers

GapSkin.Enable = 1;
GapSkin.Width = 50;
GapSkin.ElectricalModelType = 'lumped';
GapSkin.Lumped.Electrical.ConductionType = 'p-type';
GapSkin.Lumped.Electrical.RsheetEnable = 1; % in reality, every skin has some conduction (e.g. by charge-induced accumulation or inversion layer); also required to apply P/N interface shunt
GapSkin.Lumped.Electrical.Rsheet = 5000; % very high value, e.g. from inversion layer conduction
GapSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
GapSkin.Lumped.Electrical.NonContactedRecombination.J0 = 2e-15;
GapSkin.Lumped.Optical.Internal.Rint = 0.9;
GapSkin.Lumped.Optical.Internal.Diffuse = 1;
GapSkin.Lumped.Optical.Internal.ApppType = 'user';
GapSkin.Lumped.Optical.Internal.Appp = 0.001; % negligible parasitic absorption in gap-region material layers
