% Quokka3 example for setting up IBC geometry using the simplified 'IBC' syntax
% all properties are made-up, does not represent a specific real cell

% this example defines a 'multi-domain' domain, efficiently representing a full-cell geometry including perimeter and edges

% (c) 2025 Andreas Fell

Syntax = 'IBC';

DomainType = 'multi-domain';

CellThickness = 120;
CellSizeX = 105 mm; % half-cell design
CellSizeY = 210 mm;

BusbarNumber = 5; % each for n-type and p-type, i.e. 10 total busbars
FingerNumber = 50; % each for n-type and p-type, i.e. 100 total fingers
OuterFingerPolarity = 'p-type'; % first and last finger is p-type

IncludeSolderPads = 1; % wether to consider solder-pads in a full-cell geometry
PadNumber = 10; % not any number allowed to due symmetry requirements; possible numbers are suggested in an error message when setting an invalid number
FingersToOuterPad = 3; % the first pad on each side is placed on the 3rd p-type finger

NSkin.Width = 0.5mm;
NContact.Width = 80;
NContact.OhmicResistivity = 3e-4;
NFinger.Width = 80;
NFinger.Rsheet = 3e-3;
NFinger.Length = 21mm;

NBusbar.SkinWidth = 500;
NBusbar.Width = 250;
NBusbar.Rsheet = 3e-3;
NBusbar.ContactEnable = 1;
NBusbar.Contact.OhmicResistivity = 3e-4;

NPad.SkinSizeX = 2mm;
NPad.SizeX = 1mm;
NPad.ContactResistivity = 1e-6;


PSkin.WidthFromPitch = 1; % means that the width of the P-region is calculated from finger pitch, gap width and N-region width
PContact.Width = 80;
PContact.OhmicResistivity = 3e-4;
PFinger.Width = 80;
PFinger.Rsheet = 3e-3;
PFinger.Length = 21mm;

PBusbar.SkinWidth = 500;
PBusbar.Width = 250;
PBusbar.Rsheet = 3e-3;
PBusbar.ContactEnable = 1;
PBusbar.Contact.OhmicResistivity = 3e-4;

PPad.SkinSizeX = 2mm;
PPad.SizeX = 1mm;
PPad.ContactResistivity = 1e-6;


Solver.SolutionType = 'light JV-curve';
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;


Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.TextZ.FrontText.Type = 'from Rtot'; % Text of front side is determined from rear Rtot measurement, settingsgroup Optical.TextZ.FrontRtot
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local'; % light-trapping is set to be modelled from internal optical properties of the skins; enables to consider current changes when area-fraction of rear-side skin region changes (e.g. when changing N/P region ratio)
Optical.TextZ.FrontRtot.Type = 'file';
Optical.TextZ.FrontRtot.File = 'Rtot_front.txt';
Optical.TextZ.FrontRtot.Extrapolation = 'RT-TMM';
Optical.TextZ.FrontRtot.SurfaceMorphology = 'Rantex-default';
Optical.TextZ.FrontRtot.MetalCorrection = 1;
Optical.TextZ.FrontRtot.MetalReflectivity.Type = 'file';
Optical.TextZ.FrontRtot.MetalReflectivity.File = 'Wittek_metal_R.txt';
Optical.TextZ.FrontRtot.SampleThickness = 160 um;
Optical.TextZ.FrontRtot.SampleTemperature = 20 degC;
Optical.ScaleGeneration = 1;


Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 2;
Bulk.Electrical.Recombination.Type = 'intrinsic plus fixed-lifetime';
Bulk.Electrical.Recombination.FixedLifetime = 5ms;


FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 250;
FullFrontSkin.Lumped.Electrical.ConductionType = 'n-type';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 2e-15;
FullFrontSkin.Lumped.Optical.Internal.Rint = 0.92; % ideal Lambertian front side reflectivity
FullFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

NSkin.ElectricalModelType = 'lumped';
NSkin.Lumped.Electrical.RsheetEnable = 1;
NSkin.Lumped.Electrical.Rsheet = 100;
NSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
NSkin.Lumped.Electrical.NonContactedRecombination.J0 = 2e-15;
NSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
NSkin.Lumped.Electrical.ContactedRecombination.J0 = 20e-15;
NSkin.Lumped.Optical.Internal.Rint = 0.9;
NSkin.Lumped.Optical.Internal.Diffuse = 1;
NSkin.Lumped.Optical.Internal.ApppType = 'user';
NSkin.Lumped.Optical.Internal.Appp = 0.02; % some parasitic absorption in N-region material layers

PSkin.ElectricalModelType = 'lumped';
PSkin.Lumped.Electrical.RsheetEnable = 1;
PSkin.Lumped.Electrical.Rsheet = 100;
PSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
PSkin.Lumped.Electrical.NonContactedRecombination.J0 = 5e-15;
PSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
PSkin.Lumped.Electrical.ContactedRecombination.J0 = 50e-15;
PSkin.Lumped.Optical.Internal.Rint = 0.9;
PSkin.Lumped.Optical.Internal.Diffuse = 1;
PSkin.Lumped.Optical.Internal.ApppType = 'user';
PSkin.Lumped.Optical.Internal.Appp = 0.05; % high parasitic absorption in P-region material layers


NBusbarPerimeterSkin.Enable = 1;
NBusbarPerimeterSkin.Width = 2mm;
NBusbarPerimeterSkin.ElectricalModelType = 'lumped';
NBusbarPerimeterSkin.Lumped.Electrical.ConductionType = 'n-type';
NBusbarPerimeterSkin.Lumped.Electrical.RsheetEnable = 1;
NBusbarPerimeterSkin.Lumped.Electrical.Rsheet = 100;
NBusbarPerimeterSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
NBusbarPerimeterSkin.Lumped.Electrical.NonContactedRecombination.J0 = 5e-15;
NBusbarPerimeterSkin.Lumped.Optical.Internal.Rint = 0.9;
NBusbarPerimeterSkin.Lumped.Optical.Internal.Diffuse = 1;
NBusbarPerimeterSkin.Lumped.Optical.Internal.ApppType = 'user';
NBusbarPerimeterSkin.Lumped.Optical.Internal.Appp = 0.02; % some parasitic absorption in N-region material layers


PBusbarPerimeterSkin.Enable = 1;
PBusbarPerimeterSkin.Width = 2mm;
PBusbarPerimeterSkin.ElectricalModelType = 'lumped';
PBusbarPerimeterSkin.Lumped.Electrical.ConductionType = 'p-type';
PBusbarPerimeterSkin.Lumped.Electrical.RsheetEnable = 1;
PBusbarPerimeterSkin.Lumped.Electrical.Rsheet = 100;
PBusbarPerimeterSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
PBusbarPerimeterSkin.Lumped.Electrical.NonContactedRecombination.J0 = 5e-15;
PBusbarPerimeterSkin.Lumped.Optical.Internal.Rint = 0.9;
PBusbarPerimeterSkin.Lumped.Optical.Internal.Diffuse = 1;
PBusbarPerimeterSkin.Lumped.Optical.Internal.ApppType = 'user';
PBusbarPerimeterSkin.Lumped.Optical.Internal.Appp = 0.05; % high parasitic absorption in P-region material layers


EastPerimeterSkin.Enable = 1;
EastPerimeterSkin.Width = 2mm;
EastPerimeterSkin.ElectricalModelType = 'lumped';
EastPerimeterSkin.Lumped.Electrical.ConductionType = 'p-type';
EastPerimeterSkin.Lumped.Electrical.RsheetEnable = 1;
EastPerimeterSkin.Lumped.Electrical.Rsheet = 100;
EastPerimeterSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
EastPerimeterSkin.Lumped.Electrical.NonContactedRecombination.J0 = 5e-15;
EastPerimeterSkin.Lumped.Optical.Internal.Rint = 0.9;
EastPerimeterSkin.Lumped.Optical.Internal.Diffuse = 1;
EastPerimeterSkin.Lumped.Optical.Internal.ApppType = 'user';
EastPerimeterSkin.Lumped.Optical.Internal.Appp = 0.05; % high parasitic absorption in P-region material layers


WestPerimeterSkin.Enable = 1;
WestPerimeterSkin.Width = 2mm;
WestPerimeterSkin.ElectricalModelType = 'lumped';
WestPerimeterSkin.Lumped.Electrical.ConductionType = 'p-type';
WestPerimeterSkin.Lumped.Electrical.RsheetEnable = 1;
WestPerimeterSkin.Lumped.Electrical.Rsheet = 100;
WestPerimeterSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
WestPerimeterSkin.Lumped.Electrical.NonContactedRecombination.J0 = 5e-15;
WestPerimeterSkin.Lumped.Optical.Internal.Rint = 0.9;
WestPerimeterSkin.Lumped.Optical.Internal.Diffuse = 1;
WestPerimeterSkin.Lumped.Optical.Internal.ApppType = 'user';
WestPerimeterSkin.Lumped.Optical.Internal.Appp = 0.05; % high parasitic absorption in P-region material layers
